@@ -1,6 +1,7 @@
 from ffun.librarian.processors import base
 from ffun.library.entities import Entry
-from ffun.ontology.entities import NormalizationMode, RawTag, TagCategory
+from ffun.ontology.entities import RawTag
+from ffun.tags.entities import TagCategory
 
 
 class Processor(base.Processor):
@@ -12,7 +13,8 @@ class Processor(base.Processor):
         for external_tag in entry.external_tags:
             tags.append(
                 RawTag(
-                    raw_uid=external_tag, normalization=NormalizationMode.preserve, categories={TagCategory.feed_tag}
+                    raw_uid=external_tag,
+                    categories={TagCategory.feed_tag},
                 )
             )
 
