@@ -1,7 +1,8 @@
 from ffun.core import logging
 from ffun.librarian.processors import base
 from ffun.library.entities import Entry
-from ffun.ontology.entities import NormalizationMode, RawTag
+from ffun.ontology.entities import RawTag
+from ffun.tags.entities import TagCategory
 
 logger = logging.get_module_logger()
 
@@ -14,7 +15,7 @@ class Processor(base.Processor):
             return [
                 RawTag(
                     raw_uid="upper-case-title",
-                    normalization=NormalizationMode.final,
+                    categories={TagCategory.special},
                 )
             ]
 
